@@ -31,6 +31,8 @@
 #include <libgnomevfs/gnome-vfs-file-size.h>
 #include <libgnomevfs/gnome-vfs-async-ops.h>
 #include <libgnomevfs/gnome-vfs-mime-handlers.h>
+#include <libgnomeui/gnome-thumbnail.h>
+#include <gdk-pixbuf/gdk-pixbuf.h>
 #include "typedefs.h"
 
 #define SPECIAL_DIR(x) (! strcmp (x, "..") || ! strcmp (x, "."))
@@ -52,6 +54,7 @@ struct _PathListData {
 	DoneFunc          interrupt_func;
 	gpointer          interrupt_data;
 	gboolean          interrupted;
+	GHashTable       *hidden_files;
 };
 
 typedef struct {
@@ -62,19 +65,19 @@ typedef struct {
 PathListData *      path_list_data_new            (void);
 void                path_list_data_free           (PathListData     *dli);
 void                path_list_handle_free         (PathListHandle   *handle);
-PathListHandle *    path_list_async_new           (const char       *uri, 
+PathListHandle *    path_list_async_new           (const char       *uri,
 						   PathListDoneFunc  f,
 						   gpointer          data);
 void                path_list_async_interrupt     (PathListHandle   *handle,
 						   DoneFunc          f,
 						   gpointer          data);
-gboolean            path_list_new                 (const char       *path, 
-						   GList           **files, 
+gboolean            path_list_new                 (const char       *path,
+						   GList           **files,
 						   GList           **dirs);
 GList *             path_list_dup                 (GList            *path_list);
 void                path_list_free                (GList            *list);
 void                path_list_print               (GList            *list);
-GList *             path_list_find_path           (GList            *list, 
+GList *             path_list_find_path           (GList            *list,
 						   const char       *path);
 
 /* Directory utils */
@@ -99,21 +102,36 @@ gboolean            visit_rc_directory_sync       (const char       *rc_dir,
 						   VisitFunc         do_something,
 						   gpointer          data);
 
-/* File utils */ 
+/* File utils */
 
-gboolean            file_is_image                 (const char       *name,
+gboolean	    mime_type_is_image	          (const char       *mime_type);
+gboolean            mime_type_is_video            (const char       *mime_type);
+gboolean            mime_type_is_audio            (const char       *mime_type);
+gboolean	    file_is_image 		  (const gchar      *name,
 						   gboolean          fast_file_type);
+gboolean            file_is_video                 (const gchar      *name,
+                                                   gboolean          fast_file_type);
+gboolean            file_is_audio                 (const gchar      *name,
+                                                   gboolean          fast_file_type);
+gboolean            file_is_image_video_or_audio  (const gchar      *name,
+                                                   gboolean          fast_file_type);
 gboolean            file_is_hidden                (const char       *name);
-gboolean            file_copy                     (const char       *from, 
+gboolean            file_copy                     (const char       *from,
 						   const char       *to);
-gboolean            file_move                     (const char       *from, 
+gboolean            file_move                     (const char       *from,
 						   const char       *to);
-gboolean            file_rename                   (const gchar      *old_path,
-						   const gchar      *new_path);
+GnomeVFSResult      file_rename                   (const char       *old_path,
+						   const char       *new_path);
 gboolean            file_unlink                   (const char       *path);
+gboolean            mime_type_is                  (const char       *mime_type,
+	      				 	   const char       *value);
+gboolean            image_is_type                 (const char       *name,
+	       					   const char       *type,
+	       					   gboolean          fast_file_type);
 gboolean            image_is_jpeg                 (const char       *name);
+gboolean            mime_type_is_raw              (const char       *name);
 gboolean            image_is_gif                  (const char       *name);
-gboolean            image_is_gif__accurate        (const char       *name);
+gboolean            path_exists                   (const char       *s);
 gboolean            path_is_file                  (const char       *s);
 gboolean            path_is_dir                   (const char       *s);
 GnomeVFSFileSize    get_file_size                 (const char       *s);
@@ -131,6 +149,7 @@ const char *        get_catalog_path_from_uri     (const char       *uri);
 const char *        get_search_path_from_uri      (const char       *uri);
 const char *        remove_scheme_from_uri        (const char       *uri);
 char *              get_uri_scheme                (const char       *uri);
+char *              get_base_uri                  (const char       *uri);
 gboolean            uri_has_scheme                (const char       *uri);
 gboolean            uri_scheme_is_file            (const char       *uri);
 gboolean            uri_scheme_is_catalog         (const char       *uri);
@@ -138,14 +157,16 @@ gboolean            uri_scheme_is_search          (const char       *uri);
 char *              get_uri_from_path             (const char       *path);
 char *              get_uri_display_name          (const char       *uri);
 G_CONST_RETURN char*file_name_from_path           (const char       *path);
+char *              get_local_path_from_uri       (const char       *uri);
 gboolean            path_in_path                  (const char       *path_src,
 						   const char       *path_dest);
 int                 uricmp                        (const char       *uri1,
 						   const char       *uri2);
 gboolean            same_uri                      (const char       *uri1,
 						   const char       *uri2);
+char               *basename_for_display          (const char       *uri);
 
-char *              get_path_relative_to_dir      (const char       *filename, 
+char *              get_path_relative_to_dir      (const char       *filename,
 						   const char       *destdir);
 char *              remove_level_from_path        (const char       *path);
 
@@ -156,11 +177,12 @@ GnomeVFSURI *       new_uri_from_path             (const char       *path);
 char *              new_path_from_uri             (GnomeVFSURI      *uri);
 GnomeVFSResult      resolve_all_symlinks          (const char       *text_uri,
 						   char            **resolved_text_uri);
+gboolean            uri_is_root                   (const char       *uri);
 
 /* Catalogs */
 
 char *              get_catalog_full_path         (const char       *relative_path);
-gboolean            delete_catalog_dir            (const char       *full_path, 
+gboolean            delete_catalog_dir            (const char       *full_path,
 						   gboolean          recursive,
 						   GError          **error);
 gboolean            delete_catalog                (const char       *full_path,
@@ -175,7 +197,7 @@ char *              shell_escape                  (const char       *filename);
 
 /* extesion */
 
-gboolean            file_extension_is             (const char       *filename, 
+gboolean            file_extension_is             (const char       *filename,
 						   const char       *ext);
 const char *        get_filename_extension        (const char       *filename);
 char *              remove_extension_from_path    (const char       *path);
@@ -183,7 +205,10 @@ char *              remove_extension_from_path    (const char       *path);
 /* temp */
 
 char *              get_temp_dir_name             (void);
-char *              get_temp_file_name            (const char       *ext);
+char *              get_temp_file_name            (const char       *tmpdir,
+						   const char       *ext);
+void		    remove_temp_file_and_dir      (char             *tmp_file);
+
 
 /* VFS extensions */
 
@@ -200,7 +225,26 @@ const char*         get_file_mime_type            (const char       *path,
 						   gboolean          fast_file_type);
 const char *        get_mime_type_from_ext        (const char       *ext);
 gboolean            is_mime_type_writable         (const char       *mime_type);
-gboolean            check_permissions             (const char       *path, 
+gboolean            check_permissions             (const char       *path,
 						   int               mode);
+gboolean	    is_local_file                 (const char       *filename);
+void	            prune_cache			  (void);
+char* 		    obtain_local_file             (const char       *remote_filename);
+gboolean	    copy_cache_file_to_remote_uri (const char       *local_filename,
+                                                   const char       *dest_uri);
+GHashTable *        read_dot_hidden_file          (const char       *uri);
 
+/* Pixbuf + VFS */
+GdkPixbuf*	    gth_pixbuf_new_from_uri	      (const char            *filename,
+						       GError 	            **error,
+				                       gint                   requested_width_if_used,
+				                       gint                   requested_height_if_used,
+				                       const char            *mime_type);
+
+GdkPixbufAnimation* gth_pixbuf_animation_new_from_uri (const char            *filename,
+						       GError               **error,
+						       gint                   requested_width_if_used,
+						       gint	              requested_height_if_used,
+						       GnomeThumbnailFactory *factory,
+						       const char            *mime_type);
 #endif /* FILE_UTILS_H */
